Index: inundation-numpy-branch/pyvolution/_test_sww2domain.py
===================================================================
--- inundation-numpy-branch/pyvolution/_test_sww2domain.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/_test_sww2domain.py	(revision 3514)
@@ -61,5 +61,5 @@
 ##NOW TEST IT!!!
 
-from data_manager import sww2domain
+from anuga.pyvolution.data_manager import sww2domain
 from Numeric import allclose
 
Index: inundation-numpy-branch/pyvolution/_test_sww2domain2.py
===================================================================
--- inundation-numpy-branch/pyvolution/_test_sww2domain2.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/_test_sww2domain2.py	(revision 3514)
@@ -59,5 +59,5 @@
 ##NOW TEST IT!!!
 
-from data_manager import sww2domain
+from anuga.pyvolution.data_manager import sww2domain
 from Numeric import allclose
 
Index: inundation-numpy-branch/pyvolution/bed_w_file_boundary.py
===================================================================
--- inundation-numpy-branch/pyvolution/bed_w_file_boundary.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/bed_w_file_boundary.py	(revision 3514)
@@ -57,5 +57,5 @@
 
 #Convert ASCII file to NetCDF (Which is what we really like!)
-from data_manager import timefile2swww        
+from anuga.pyvolution.data_manager import timefile2swww        
 timefile2swww(filename, quantity_names = domain.conserved_quantities)
 
Index: inundation-numpy-branch/pyvolution/check_sww_tsh.py
===================================================================
--- inundation-numpy-branch/pyvolution/check_sww_tsh.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/check_sww_tsh.py	(revision 3514)
@@ -5,5 +5,5 @@
 from os import sep, path
 
-import data_manager
+import anuga.pyvolution.data_manager
 from load_mesh.loadASCII import import_mesh_file
 from shallow_water import Domain
Index: inundation-numpy-branch/pyvolution/combine_pts.py
===================================================================
--- inundation-numpy-branch/pyvolution/combine_pts.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/combine_pts.py	(revision 3514)
@@ -5,5 +5,5 @@
 """
 
-from utilities.polygon import outside_polygon, inside_polygon
+from anuga.utilities.polygon import outside_polygon, inside_polygon
 from Numeric import take, concatenate
 import time
Index: inundation-numpy-branch/pyvolution/data_manager.py
===================================================================
--- inundation-numpy-branch/pyvolution/data_manager.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/data_manager.py	(revision 3514)
@@ -248,5 +248,5 @@
             #Create new file
             fid.institution = 'Geoscience Australia'
-            fid.description = 'Output from pyvolution suitable for plotting'
+            fid.description = 'Output from anuga.pyvolution suitable for plotting'
 
             if domain.smooth:
@@ -1572,6 +1572,6 @@
     from Numeric import array2string
 
-    from utilities.polygon import inside_polygon, outside_polygon, separate_points_by_polygon
-    from util import apply_expression_to_dictionary
+    from anuga.utilities.polygon import inside_polygon, outside_polygon, separate_points_by_polygon
+    from anuga.pyvolution.util import apply_expression_to_dictionary
 
     msg = 'Format must be either asc or ers'
@@ -2571,5 +2571,5 @@
     from Numeric import array
     from config import time_format
-    from utilities.numerical_tools import ensure_numeric    
+    from anuga.utilities.numerical_tools import ensure_numeric    
 
 
@@ -3093,7 +3093,7 @@
     from pmesh2domain import pmesh_to_domain_instance
     import time, os
-    from data_manager import get_dataobject
+    from anuga.pyvolution.data_manager import get_dataobject
     from os import sep, path
-    from utilities.numerical_tools import mean
+    from anuga.utilities.numerical_tools import mean
 
     if verbose == True:print 'Creating domain from', filename
Index: inundation-numpy-branch/pyvolution/data_manager_obsolete_stuff.py
===================================================================
--- inundation-numpy-branch/pyvolution/data_manager_obsolete_stuff.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/data_manager_obsolete_stuff.py	(revision 3514)
@@ -221,5 +221,5 @@
     from Numeric import array, Float, concatenate, NewAxis, zeros,\
          sometrue
-    from utilities.polygon import inside_polygon
+    from anuga.utilities.polygon import inside_polygon
 
     #FIXME: Should be variable
Index: inundation-numpy-branch/pyvolution/domain.py
===================================================================
--- inundation-numpy-branch/pyvolution/domain.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/domain.py	(revision 3514)
@@ -238,5 +238,5 @@
         """
 
-        from util import apply_expression_to_dictionary
+        from anuga.pyvolution.util import apply_expression_to_dictionary
         return apply_expression_to_dictionary(expression, self.quantities)
 
Index: inundation-numpy-branch/pyvolution/flatbed.py
===================================================================
--- inundation-numpy-branch/pyvolution/flatbed.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/flatbed.py	(revision 3514)
@@ -13,5 +13,5 @@
      Constant_height
 from Numeric import array
-from util import Polygon_function, read_polygon
+from anuga.pyvolution.util import Polygon_function, read_polygon
 
 
Index: inundation-numpy-branch/pyvolution/general_mesh.py
===================================================================
--- inundation-numpy-branch/pyvolution/general_mesh.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/general_mesh.py	(revision 3514)
@@ -50,5 +50,5 @@
 
 
-        This is a cut down version of mesh from pyvolution mesh.py
+        This is a cut down version of mesh from anuga.pyvolution mesh.py
     """
 
Index: inundation-numpy-branch/pyvolution/generic_boundary_conditions.py
===================================================================
--- inundation-numpy-branch/pyvolution/generic_boundary_conditions.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/generic_boundary_conditions.py	(revision 3514)
@@ -131,5 +131,5 @@
         from Numeric import array
         from config import time_format
-        from util import File_function
+        from anuga.pyvolution.util import File_function
 
         Boundary.__init__(self)
@@ -181,5 +181,5 @@
         from Numeric import array, zeros, Float
         from config import time_format
-        from util import file_function
+        from anuga.pyvolution.util import file_function
 
         Boundary.__init__(self)
Index: inundation-numpy-branch/pyvolution/island.py
===================================================================
--- inundation-numpy-branch/pyvolution/island.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/island.py	(revision 3514)
@@ -13,5 +13,5 @@
      Constant_height
 from Numeric import array
-from util import Polygon_function, read_polygon
+from anuga.pyvolution.util import Polygon_function, read_polygon
 from math import exp
 
Index: inundation-numpy-branch/pyvolution/least_squares.py
===================================================================
--- inundation-numpy-branch/pyvolution/least_squares.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/least_squares.py	(revision 3514)
@@ -25,8 +25,8 @@
 
 #FIXME (Ole): Meshes to move somewhere else
-from pyvolution.mesh import Mesh
-from utilities.sparse import Sparse, Sparse_CSR
-from utilities.cg_solve import conjugate_gradient, VectorShapeError
-from utilities.numerical_tools import ensure_numeric, mean, gradient
+from anuga.pyvolution.mesh import Mesh
+from anuga.utilities.sparse import Sparse, Sparse_CSR
+from anuga.utilities.cg_solve import conjugate_gradient, VectorShapeError
+from anuga.utilities.numerical_tools import ensure_numeric, mean, gradient
 
 
@@ -441,6 +441,6 @@
         #Maybe we need some sort of blocking
 
-        from pyvolution.quad import build_quadtree
-	from utilities.polygon import inside_polygon
+        from anuga.pyvolution.quad import build_quadtree
+	from anuga.utilities.polygon import inside_polygon
 	
 
@@ -1134,5 +1134,5 @@
         from math import pi, cos, sin, sqrt
         from Numeric import zeros, Float
-        from utilities.numerical_tools import mean        
+        from anuga.utilities.numerical_tools import mean        
 
         if self.spatial is True:
Index: inundation-numpy-branch/pyvolution/mesh.py
===================================================================
--- inundation-numpy-branch/pyvolution/mesh.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/mesh.py	(revision 3514)
@@ -492,5 +492,5 @@
         from config import epsilon
         from math import pi
-        from utilities.numerical_tools import anglediff
+        from anuga.utilities.numerical_tools import anglediff
 
         N = self.number_of_elements
@@ -616,5 +616,5 @@
         """
 
-        from utilities.numerical_tools import histogram
+        from anuga.utilities.numerical_tools import histogram
 
         vertex_coordinates = self.vertex_coordinates
Index: inundation-numpy-branch/pyvolution/mesh_factory.py
===================================================================
--- inundation-numpy-branch/pyvolution/mesh_factory.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/mesh_factory.py	(revision 3514)
@@ -334,5 +334,5 @@
     """
 
-    from util import anglediff
+    from anuga.pyvolution.util import anglediff
     from math import pi
     import os.path
@@ -449,5 +449,5 @@
 
     from math import pi
-    from util import anglediff
+    from anuga.pyvolution.util import anglediff
 
 
Index: inundation-numpy-branch/pyvolution/mesh_factory_all.py
===================================================================
--- inundation-numpy-branch/pyvolution/mesh_factory_all.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/mesh_factory_all.py	(revision 3514)
@@ -351,5 +351,5 @@
     """
 
-    from util import anglediff
+    from anuga.pyvolution.util import anglediff
     from math import pi
     import os.path
@@ -466,5 +466,5 @@
 
     from math import pi
-    from util import anglediff
+    from anuga.pyvolution.util import anglediff
 
 
Index: inundation-numpy-branch/pyvolution/pressure_force.py
===================================================================
--- inundation-numpy-branch/pyvolution/pressure_force.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/pressure_force.py	(revision 3514)
@@ -49,5 +49,5 @@
 def cyclone(domain):
     from config import rho_w 
-    from util import gradient
+    from anuga.pyvolution.util import gradient
 
     xmom = domain.quantities['xmomentum'].explicit_update
Index: inundation-numpy-branch/pyvolution/quantity.py
===================================================================
--- inundation-numpy-branch/pyvolution/quantity.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/quantity.py	(revision 3514)
@@ -267,5 +267,5 @@
         """
 
-        from geospatial_data.geospatial_data import Geospatial_data
+        from anuga.geospatial_data.geospatial_data import Geospatial_data
         from types import FloatType, IntType, LongType, ListType, NoneType
 
@@ -613,5 +613,5 @@
 
 
-        from utilities.numerical_tools import ensure_numeric
+        from anuga.utilities.numerical_tools import ensure_numeric
         from least_squares import fit_to_mesh
         from coordinate_transforms.geo_reference import Geo_reference
@@ -685,5 +685,5 @@
 
         from load_mesh.loadASCII import import_points_file
-        from geospatial_data.geospatial_data import points_dictionary2geospatial_data
+        from anuga.geospatial_data.geospatial_data import points_dictionary2geospatial_data
 
         from types import StringType
@@ -1296,5 +1296,5 @@
 
 
-from utilities import compile
+from anuga.utilities import compile
 if compile.can_use_C_extension('quantity_ext.c'):
     #Replace python version with c implementations
Index: inundation-numpy-branch/pyvolution/realtime_visualisation.py
===================================================================
--- inundation-numpy-branch/pyvolution/realtime_visualisation.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/realtime_visualisation.py	(revision 3514)
@@ -200,5 +200,5 @@
 
     #print scene.forward
-    #FIXME: Use smoother from pyvolution instead
+    #FIXME: Use smoother from anuga.pyvolution instead
     if domain.smooth:
         #Get all average point values
Index: inundation-numpy-branch/pyvolution/shallow_water.py
===================================================================
--- inundation-numpy-branch/pyvolution/shallow_water.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/shallow_water.py	(revision 3514)
@@ -62,5 +62,5 @@
 from generic_boundary_conditions import Transmissive_boundary
 
-from utilities.numerical_tools import gradient, mean
+from anuga.utilities.numerical_tools import gradient, mean
 
 
@@ -285,5 +285,5 @@
         """
 
-        import data_manager
+        import anuga.pyvolution.data_manager
 
         #Initialise writer
@@ -1779,5 +1779,5 @@
 
 
-from utilities import compile
+from anuga.utilities import compile
 if compile.can_use_C_extension('shallow_water_ext.c'):
     #Replace python version with c implementations
Index: inundation-numpy-branch/pyvolution/shallow_water_kinetic.py
===================================================================
--- inundation-numpy-branch/pyvolution/shallow_water_kinetic.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/shallow_water_kinetic.py	(revision 3514)
@@ -94,5 +94,5 @@
 
         #Reduction operation for get_vertex_values
-        from util import mean
+        from anuga.pyvolution.util import mean
         self.reduction = mean
         #self.reduction = min  #Looks better near steep slopes
@@ -245,5 +245,5 @@
         """
 
-        import data_manager
+        import anuga.pyvolution.data_manager
 
         #Initialise writer
@@ -1169,5 +1169,5 @@
     """
 
-    from util import gradient
+    from anuga.pyvolution.util import gradient
     from Numeric import zeros, Float, array, sum
 
@@ -1772,5 +1772,5 @@
 
 
-from utilities import compile
+from anuga.utilities import compile
 if compile.can_use_C_extension('shallow_water_kinetic_ext.c'):
     #Replace python version with c implementations
Index: inundation-numpy-branch/pyvolution/test_data_manager.py
===================================================================
--- inundation-numpy-branch/pyvolution/test_data_manager.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/test_data_manager.py	(revision 3514)
@@ -5,13 +5,13 @@
 import copy
 from Numeric import zeros, array, allclose, Float
-from utilities.numerical_tools import mean
+from anuga.utilities.numerical_tools import mean
 import tempfile
 import os
 from Scientific.IO.NetCDF import NetCDFFile
 
-from data_manager import *
+from anuga.pyvolution.data_manager import *
 from shallow_water import *
 from config import epsilon
-import data_manager
+import anuga.pyvolution.data_manager
 
 from coordinate_transforms.geo_reference import Geo_reference
@@ -2528,5 +2528,5 @@
 	#Import the example's file as a new domain
 	##########################################
-	from data_manager import sww2domain
+	from anuga.pyvolution.data_manager import sww2domain
 	from Numeric import allclose
         import os
@@ -2665,5 +2665,5 @@
 	#Import the file as a new domain
         ##################################
-	from data_manager import sww2domain
+	from anuga.pyvolution.data_manager import sww2domain
 	from Numeric import allclose
         import os
@@ -2703,5 +2703,5 @@
 
     #def test_weed(self):
-	from data_manager import weed
+	from anuga.pyvolution.data_manager import weed
 
         coordinates1 = [[0.,0.],[1.,0.],[1.,1.],[1.,0.],[2.,0.],[1.,1.]]
@@ -2776,5 +2776,5 @@
 	#Import the example's file as a new domain
 	##########################################
-	from data_manager import sww2domain
+	from anuga.pyvolution.data_manager import sww2domain
 	from Numeric import allclose
         import os
@@ -3077,5 +3077,5 @@
         from Scientific.IO.NetCDF import NetCDFFile
 
-        import data_manager
+        import anuga.pyvolution.data_manager
         #Write test asc file
         filename = tempfile.mktemp(".000")
Index: inundation-numpy-branch/pyvolution/test_generic_boundary_conditions.py
===================================================================
--- inundation-numpy-branch/pyvolution/test_generic_boundary_conditions.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/test_generic_boundary_conditions.py	(revision 3514)
@@ -152,5 +152,5 @@
         #Convert ASCII file to NetCDF (Which is what we really like!)
         
-        from data_manager import timefile2netcdf                
+        from anuga.pyvolution.data_manager import timefile2netcdf                
         timefile2netcdf(filename, quantity_names = ['stage', 'ymomentum'])
         
@@ -246,5 +246,5 @@
 
         #Convert ASCII file to NetCDF (Which is what we really like!)
-        from data_manager import timefile2netcdf               
+        from anuga.pyvolution.data_manager import timefile2netcdf               
         timefile2netcdf(filename, quantity_names = ['stage', 'xmomentum'])
 
Index: inundation-numpy-branch/pyvolution/test_interpolate_sww.py
===================================================================
--- inundation-numpy-branch/pyvolution/test_interpolate_sww.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/test_interpolate_sww.py	(revision 3514)
@@ -8,9 +8,9 @@
 import unittest
 from Numeric import zeros, array, allclose, Float
-from util import mean
+from anuga.pyvolution.util import mean
 
 from interpolate_sww import *
 from shallow_water import *
-from data_manager import *
+from anuga.pyvolution.data_manager import *
 #from config import epsilon
 
Index: inundation-numpy-branch/pyvolution/test_least_squares.py
===================================================================
--- inundation-numpy-branch/pyvolution/test_least_squares.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/test_least_squares.py	(revision 3514)
@@ -1085,5 +1085,5 @@
         #Check basic interpolation of one quantity using averaging
         #(no interpolation points or spatial info)
-        from utilities.numerical_tools import mean        
+        from anuga.utilities.numerical_tools import mean        
         I = Interpolation_function(time, [mean(Q[0,:]),
                                           mean(Q[1,:]),
Index: inundation-numpy-branch/pyvolution/test_mesh.py
===================================================================
--- inundation-numpy-branch/pyvolution/test_mesh.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/test_mesh.py	(revision 3514)
@@ -15,5 +15,5 @@
 from numpy import allclose, array, zeros, Float
 
-from utilities.polygon import inside_polygon
+from anuga.utilities.polygon import inside_polygon
 
 def distance(x, y):
Index: inundation-numpy-branch/pyvolution/test_quantity.py
===================================================================
--- inundation-numpy-branch/pyvolution/test_quantity.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/test_quantity.py	(revision 3514)
@@ -280,5 +280,5 @@
     def test_set_values_using_least_squares(self):
 
-        from geospatial_data.geospatial_data import Geospatial_data
+        from anuga.geospatial_data.geospatial_data import Geospatial_data
         
         quantity = Quantity(self.mesh4)
@@ -331,5 +331,5 @@
 
         from domain import Domain
-        from geospatial_data.geospatial_data import Geospatial_data        
+        from anuga.geospatial_data.geospatial_data import Geospatial_data        
         from coordinate_transforms.geo_reference import Geo_reference
         from least_squares import fit_to_mesh
@@ -389,5 +389,5 @@
         quantity.vertex_values[:] = 0.0
         
-        from geospatial_data.geospatial_data import Geospatial_data
+        from anuga.geospatial_data.geospatial_data import Geospatial_data
         geo = Geospatial_data(data_points, z, data_georef)
 
@@ -1062,5 +1062,5 @@
         from mesh_factory import rectangular
         from shallow_water import Domain, Transmissive_boundary
-        from utilities.numerical_tools import mean
+        from anuga.utilities.numerical_tools import mean
 
         #Create basic mesh
@@ -1151,5 +1151,5 @@
         from mesh_factory import rectangular
         from shallow_water import Domain, Transmissive_boundary
-        from utilities.numerical_tools import mean
+        from anuga.utilities.numerical_tools import mean
 
 
Index: inundation-numpy-branch/pyvolution/tsh2sww.py
===================================================================
--- inundation-numpy-branch/pyvolution/tsh2sww.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/tsh2sww.py	(revision 3514)
@@ -13,6 +13,6 @@
 from pmesh2domain import pmesh_to_domain_instance
 import time, os 
-from data_manager import get_dataobject   
-from util import mean
+from anuga.pyvolution.data_manager import get_dataobject   
+from anuga.pyvolution.util import mean
 
 def tsh2sww(infilename, sww_file_name = None, verbose = False):
Index: inundation-numpy-branch/pyvolution/twolevels.py
===================================================================
--- inundation-numpy-branch/pyvolution/twolevels.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/twolevels.py	(revision 3514)
@@ -13,5 +13,5 @@
      Constant_height
 from Numeric import array
-from util import Polygon_function, read_polygon
+from anuga.pyvolution.util import Polygon_function, read_polygon
 
 
Index: inundation-numpy-branch/pyvolution/util.py
===================================================================
--- inundation-numpy-branch/pyvolution/util.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/util.py	(revision 3514)
@@ -6,5 +6,5 @@
 
 
-import utilities.polygon
+import anuga.utilities.polygon
 from warnings import warn
 
@@ -173,5 +173,5 @@
     from Scientific.IO.NetCDF import NetCDFFile
     from Numeric import array, zeros, Float, alltrue, concatenate, reshape
-    from utilities.numerical_tools import ensure_numeric    
+    from anuga.utilities.numerical_tools import ensure_numeric    
 
     #Open NetCDF file
@@ -401,8 +401,8 @@
     """Temporary Interface to new location"""
 
-    import utilities.numerical_tools as NT	
+    import anuga.utilities.numerical_tools as NT	
     
     msg = 'angle has moved from util.py.  '
-    msg += 'Please use "from utilities.numerical_tools import angle"'
+    msg += 'Please use "from anuga.utilities.numerical_tools import angle"'
     warn(msg, DeprecationWarning) 
 
@@ -412,8 +412,8 @@
     """Temporary Interface to new location"""
 
-    import utilities.numerical_tools as NT
+    import anuga.utilities.numerical_tools as NT
     
     msg = 'anglediff has moved from util.py.  '
-    msg += 'Please use "from utilities.numerical_tools import anglediff"'
+    msg += 'Please use "from anuga.utilities.numerical_tools import anglediff"'
     warn(msg, DeprecationWarning) 
 
@@ -424,8 +424,8 @@
     """Temporary Interface to new location"""
 
-    import utilities.numerical_tools as NT    
+    import anuga.utilities.numerical_tools as NT    
     
     msg = 'mean has moved from util.py.  '
-    msg += 'Please use "from utilities.numerical_tools import mean"'
+    msg += 'Please use "from anuga.utilities.numerical_tools import mean"'
     warn(msg, DeprecationWarning) 
 
@@ -436,5 +436,5 @@
 
     msg = 'point_on_line has moved from util.py.  '
-    msg += 'Please use "from utilities.polygon import point_on_line"'
+    msg += 'Please use "from anuga.utilities.polygon import point_on_line"'
     warn(msg, DeprecationWarning) 
 
@@ -445,5 +445,5 @@
 
     print 'inside_polygon has moved from util.py.  ',
-    print 'Please use "from utilities.polygon import inside_polygon"'
+    print 'Please use "from anuga.utilities.polygon import inside_polygon"'
 
     return utilities.polygon.inside_polygon(*args, **kwargs)    
@@ -453,5 +453,5 @@
 
     print 'outside_polygon has moved from util.py.  ',
-    print 'Please use "from utilities.polygon import outside_polygon"'
+    print 'Please use "from anuga.utilities.polygon import outside_polygon"'
 
     return utilities.polygon.outside_polygon(*args, **kwargs)    
@@ -462,5 +462,5 @@
 
     print 'separate_points_by_polygon has moved from util.py.  ',
-    print 'Please use "from utilities.polygon import separate_points_by_polygon"'
+    print 'Please use "from anuga.utilities.polygon import separate_points_by_polygon"'
 
     return utilities.polygon.separate_points_by_polygon(*args, **kwargs)    
@@ -472,5 +472,5 @@
 
     print 'read_polygon has moved from util.py.  ',
-    print 'Please use "from utilities.polygon import read_polygon"'
+    print 'Please use "from anuga.utilities.polygon import read_polygon"'
 
     return utilities.polygon.read_polygon(*args, **kwargs)    
@@ -481,5 +481,5 @@
 
     print 'populate_polygon has moved from util.py.  ',
-    print 'Please use "from utilities.polygon import populate_polygon"'
+    print 'Please use "from anuga.utilities.polygon import populate_polygon"'
 
     return utilities.polygon.populate_polygon(*args, **kwargs)    
Index: inundation-numpy-branch/pyvolution/view_tsh.py
===================================================================
--- inundation-numpy-branch/pyvolution/view_tsh.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/view_tsh.py	(revision 3514)
@@ -9,5 +9,5 @@
 from shallow_water import Domain
 from pmesh2domain import pmesh_to_domain_instance
-from util import file_function, Polygon_function, read_polygon
+from anuga.pyvolution.util import file_function, Polygon_function, read_polygon
 from Numeric import zeros, Float, maximum, minimum
 from realtime_visualisation_new import *

Index: inundation-numpy-branch/pyvolution/test_shallow_water.py
===================================================================
--- inundation-numpy-branch/pyvolution/test_shallow_water.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/test_shallow_water.py	(revision 3514)
@@ -6,5 +6,5 @@
 from config import g, epsilon
 from Numeric import allclose, array, zeros, ones, Float, take
-from utilities.numerical_tools import mean
+from anuga.utilities.numerical_tools import mean
 
 from shallow_water import *
@@ -967,5 +967,5 @@
         from math import pi, cos, sin, sqrt
         from config import time_format
-        from util import file_function
+        from anuga.pyvolution.util import file_function
         import time
 
@@ -1014,5 +1014,5 @@
 
         #Convert ASCII file to NetCDF (Which is what we really like!)
-        from data_manager import timefile2netcdf        
+        from anuga.pyvolution.data_manager import timefile2netcdf        
         timefile2netcdf(filename)
         os.remove(filename + '.txt')
@@ -2169,5 +2169,5 @@
 
     def test_flatbed_second_order_distribute(self):
         #Use real data from pyvolution 2
         #painfully setup and extracted.
         from mesh_factory import rectangular
@@ -2169,5 +2169,5 @@
 
     def test_flatbed_second_order_distribute(self):
-        #Use real data from pyvolution 2
+        #Use real data from anuga.pyvolution 2
         #painfully setup and extracted.
         from mesh_factory import rectangular
Index: inundation-numpy-branch/pyvolution/test_util.py
===================================================================
--- inundation-numpy-branch/pyvolution/test_util.py	(revision 3359)
+++ inundation-numpy-branch/pyvolution/test_util.py	(revision 3514)
@@ -6,7 +6,7 @@
 from math import sqrt, pi
 
-from util import *
+from anuga.pyvolution.util import *
 from config import epsilon
-from data_manager import timefile2netcdf
+from anuga.pyvolution.data_manager import timefile2netcdf
 
 
@@ -26,5 +26,5 @@
     #Geometric
     #def test_distance(self):
     #    from util import distance#
     #
     #    self.failUnless( distance([4,2],[7,6]) == 5.0,
@@ -119,5 +119,5 @@
         domain1 = Domain(points, vertices, boundary)
 
-        from utilities.numerical_tools import mean
+        from anuga.utilities.numerical_tools import mean
         domain1.reduction = mean
         domain1.smooth = True #NOTE: Mimic sww output where each vertex has
@@ -319,5 +319,5 @@
         
 
-        from utilities.numerical_tools import mean	
+        from anuga.utilities.numerical_tools import mean	
         domain1.reduction = mean
         domain1.smooth = True #NOTE: Mimic sww output where each vertex has
@@ -522,5 +522,5 @@
         from mesh_factory import rectangular
         from shallow_water import Domain
-        import data_manager
+        import anuga.pyvolution.data_manager
 
         finaltime = 1200
@@ -26,5 +26,5 @@
     #Geometric
     #def test_distance(self):
-    #    from util import distance#
+    #    from anuga.pyvolution.util import distance#
     #
     #    self.failUnless( distance([4,2],[7,6]) == 5.0,